@@ -1,5 +1,5 @@
 DEFAULT_TIMEOUT = 5
-MAX_FAN_SPEED = {"default": 10, "1.7WHF": 2, "3.5eWHF": 7}
+MAX_FAN_SPEED = {"default": 10, "1.7WHF": 2, "3.5eWHF": 7, "4.4eWHF": 6}
 STATUS_KEYS = {
     "fanspd": "fanspd",
     "doorinprocess": "doorinprocess",
